/*
 * Copyright 2010-2013, CloudBees Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.cloudbees.sdk.commands.db;

import com.cloudbees.api.BeesClient;
import com.cloudbees.api.DatabaseCreateResponse;
import com.cloudbees.sdk.cli.BeesCommand;
import com.cloudbees.sdk.cli.CLICommand;
import com.cloudbees.sdk.utils.Helper;

/**
 * @author Fabian Donze
 */
@BeesCommand(group="Database")
@CLICommand("db:create")
public class DatabaseCreate extends DatabaseBase {
    private String username;
    private String password;

    public DatabaseCreate() {
    }

    public void setUsername(String username) {
        this.username = username;
    }

    public void setPassword(String password) {
        this.password = password;
    }

    @Override
    protected boolean preParseCommandLine() {
        // add the Options
        addOption( "u", "username", true, "Database username (must be unique)" );
        addOption( "p", "password", true, "Database password" );
        addOption( "a", "account", true, "Account Name" );

        return true;
    }

    @Override
    protected boolean execute() throws Exception {
        getDatabaseName();
        if (username == null) username = Helper.promptFor("Database Username (must be unique): ", true);
        if (password == null) password = Helper.promptFor("Database Password: ", true);

        String account = getAccount();
        if (account == null) account = Helper.promptFor("Account name: ", true);

        BeesClient client = getBeesClient(BeesClient.class);
        DatabaseCreateResponse res = client.databaseCreate(account, getDatabaseName(), username, password);

        if (isTextOutput()) {
            System.out.println("database created: " + res.getDatabaseId());
        } else
            printOutput(res, DatabaseCreateResponse.class);


        return true;
    }


}
