/*
 * Copyright 2010-2013, CloudBees Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.cloudbees.sdk.commands.db;

import com.cloudbees.api.BeesClient;
import com.cloudbees.api.DatabaseSetPasswordResponse;
import com.cloudbees.sdk.cli.BeesCommand;
import com.cloudbees.sdk.cli.CLICommand;
import com.cloudbees.sdk.utils.Helper;

import java.io.IOException;

/**
 * @author Fabian Donze
 */
@BeesCommand(group="Database")
@CLICommand("db:set")
public class DatabaseSet extends DatabaseBase {
    private String password;

    public DatabaseSet() {
    }

    protected String getPassword() throws IOException {
        if (password == null) password = Helper.promptFor("Database password: ", true);
        return password;
    }

    public void setPassword(String password) {
        this.password = password;
    }

    @Override
    protected boolean preParseCommandLine() {
        // add the Options
        addOption( "p", "password", true, "The database password" );

        return true;
    }

    @Override
    protected boolean postParseCheck() {
        if (super.postParseCheck()) {
            setDatabaseName(getParameters().get(0));
            return true;
        }
        return false;
    }

    @Override
    protected boolean execute() throws Exception {
        String dbId = getDatabaseName();
        BeesClient client = getBeesClient(BeesClient.class, dbId);
        DatabaseSetPasswordResponse res = client.databaseSetPassword(dbId, getPassword());

        if (isTextOutput()) {
            if(res.isSuccess())
                System.out.println("database password set");
            else
                System.out.println("database could not be changed");
        } else
            printOutput(res, DatabaseSetPasswordResponse.class);

        return true;
    }

}
