/*
 * Copyright 2010-2013, CloudBees Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.cloudbees.sdk.commands.db;

import com.cloudbees.api.BeesClient;
import com.cloudbees.api.DatabaseSnapshotInfo;
import com.cloudbees.api.DatabaseSnapshotListResponse;
import com.cloudbees.sdk.cli.BeesCommand;
import com.cloudbees.sdk.cli.CLICommand;
import com.cloudbees.sdk.utils.Helper;

/**
 * @author Fabian Donze
 */
@BeesCommand(group="Database")
@CLICommand("db:snapshot:list")
public class DatabaseSnapshotList extends DatabaseBase {

    public DatabaseSnapshotList() {
    }

    @Override
    protected boolean execute() throws Exception {
        String dbId = getDatabaseName();
        BeesClient client = getBeesClient(BeesClient.class, dbId);
        DatabaseSnapshotListResponse res = client.databaseSnapshotList(dbId);

        if (isTextOutput()) {
            System.out.println("Snapshot   Title                          Created");
            System.out.println();
            for (DatabaseSnapshotInfo snapshotInfo: res.getSnapshots()) {
                System.out.println(s(snapshotInfo.getId(), 10)+ " " + s(snapshotInfo.getTitle(), 30)+ " " + snapshotInfo.getCreated());
            }
        } else
            printOutput(res, DatabaseSnapshotListResponse.class, DatabaseSnapshotInfo.class);

        return true;
    }

    private String s(String str, int length) {
        return Helper.getPaddedString(str, length);
    }
}
